@@ -1,4 +1,4 @@
-ascii.summary.table <- function(x, caption = "", caption.level = "", list.type = "bullet", ...) {
+ascii.summary.table <- function(x, caption = NULL, caption.level = NULL, list.type = "bullet", ...) {
     x <- as.list(capture.output(x))
     obj <- asciiList$new(x = x, caption = caption, caption.level = caption.level, list.type = list.type)
     class(obj) <- c("ascii", "proto", "environment")
